@@ -4,7 +4,7 @@
 modname = 'vcsfile'
 distname = "cubicweb-%s" % modname
 
-numversion = (1, 0, 13)
+numversion = (1, 1, 0)
 version = '.'.join(str(num) for num in numversion)
 
 copyright = '''Copyright (c) 2007-2010 LOGILAB S.A. (Paris, FRANCE).
@@ -15,12 +15,19 @@ author = "Logilab"
 author_email = "contact@logilab.fr"
 web = 'http://www.cubicweb.org/project/%s' % distname
 
-short_desc = "component to use version control systems from the CubicWeb framework"
-long_desc = """CubicWeb VCSFile component to integrate with version control systems and
-make their data available from within a CubicWeb application (currently
-works for mercurial and subversion).
+short_desc = "component to integrate version control systems data into the CubicWeb framework"
+long_desc = """\
+Summary
+-------
 
-CubicWeb is a semantic web application framework, see http://www.cubicweb.org
+This cube stores the data found in a version content manager
+repository. It currently works with subversion or mercurial repository.
+
+This cube doesn't access to the data directly. It depends on the
+logilab.devtools.vcslib library. All the repository's metadata (eg revision,
+file names, commit message, date and autor, etc) are stored as entities, and
+thus queryable via RQL, while actual files content is kept in the repository and
+fetched from there on demand.
 """
 
 from os import listdir as _listdir
@@ -49,7 +56,7 @@ for dirname in ('entities', 'views', 'sobjects', 'hooks', 'schema', 'data', 'i18
 cube_eid = None # XXX
 # used packages
 __depends_cubes__ = {}
-__depends__ = {'cubicweb': '>= 3.3.1',
+__depends__ = {'cubicweb': '>= 3.6.0',
                'logilab-mtconverter': '>= 0.7.0',
                'pysqlite': None,
                }
