@@ -50,7 +50,7 @@ def cache_handler_for_repository(repoent):
     except KeyError:
         pass
     repohdlr = build_repository_handler(repoent.eid, repoent.type, repoent.path,
-                                        repoent.encoding, repoent.req._)
+                                        repoent.encoding, repoent._cw._)
     _REPOHDLRS[repoent.eid] = repohdlr
     return repohdlr
 
