@@ -37,7 +37,7 @@ _MARKER = object()
 
 class Repository(AnyEntity):
     """customized class for Repository entities"""
-    id = 'Repository'
+    __regid__ ='Repository'
     fetch_attrs, fetch_order = fetch_config(['path', 'subpath', 'type'])
     rest_attr = 'eid' # see #XXX, using path cause pb w/ apache redirection
 
@@ -55,7 +55,7 @@ class Repository(AnyEntity):
 
     def latest_known_revision(self):
         """return the number of the latest known revision"""
-        latestrev = self.req.execute(
+        latestrev = self._cw.execute(
             'Any MAX(REVR) WHERE R eid %(r)s, REV from_repository R, '
             'REV revision REVR', {'r' : self.eid}, 'r')[0][0]
         if latestrev is None:
@@ -64,7 +64,7 @@ class Repository(AnyEntity):
 
     def branches(self):
         """return existing branches"""
-        return [b for b, in self.req.execute(
+        return [b for b, in self._cw.execute(
             'DISTINCT Any B WHERE R eid %(r)s, REV from_repository R, '
             'REV branch B', {'r' : self.eid}, 'r')]
 
@@ -73,7 +73,7 @@ class Repository(AnyEntity):
         """return latest revision of the given branch"""
         if branch is _MARKER:
             branch = self.default_branch()
-        rset = self.req.execute(
+        rset = self._cw.execute(
             'Any MAX(REV) WHERE V at_revision REV, REV branch %(branch)s, '
             'REV from_repository R, R eid %(r)s',
             {'r': self.eid, 'branch': branch}, 'r')
@@ -82,7 +82,7 @@ class Repository(AnyEntity):
         return rset.get_entity(0, 0)
 
     def versioned_file(self, directory, filename):
-        rset = self.req.execute(
+        rset = self._cw.execute(
             'Any X WHERE X is VersionedFile, X from_repository R, '
             'R eid %(repo)s, X directory %(dir)s, X name %(name)s',
             {'repo' : self.eid, 'dir' : directory, 'name' : filename})
@@ -90,12 +90,12 @@ class Repository(AnyEntity):
 
     def is_directory_deleted(self, directory):
         # XXX same MAX(X) trick as above
-        rset = self.req.execute(
+        rset = self._cw.execute(
             'Any MAX(VC), MAX(REV) GROUPBY VF '
             'WHERE VC from_revision R, R revision REV, R from_repository X, '
             'X eid %(x)s, VC content_for VF, VF directory ~= %(dir)s',
             {'x': self.eid, 'dir': directory}, 'x')
-        return not any(e for e in rset.entities() if e.id == 'VersionContent')
+        return not any(e for e in rset.entities() if e.__regid__ == 'VersionContent')
 
     # vcs write support ########################################################
 
@@ -113,14 +113,14 @@ class Repository(AnyEntity):
         if branch is _MARKER:
             branch = self.default_branch()
         if author is _MARKER:
-            author = self.req.user.login
+            author = self._cw.user.login
         parent = self.branch_head(branch)
         if parent is None and branch != parentbranch:
             parent = self.branch_head(parentbranch)
         #assert parent
         args = {'description' : msg, 'author': author, 'branch': branch,
                 'repoeid' : self.eid, 'parent': parent and parent.eid}
-        rset = self.req.execute(queries.new_revision_rql(parent), args)
+        rset = self._cw.execute(queries.new_revision_rql(parent), args)
         return rset.get_entity(0, 0)
 
     def vcs_add(self, filedir, filename, stream, strict=False,
@@ -141,7 +141,7 @@ class Repository(AnyEntity):
         if not vf:
             if extraattrs is None:
                 extraattrs = {}
-            vf = self.req.create_entity('VersionedFile',
+            vf = self._cw.create_entity('VersionedFile',
                                         from_repository=self, directory=filedir,
                                         name=filename, **extraattrs)
         elif strict:
@@ -152,20 +152,20 @@ class Repository(AnyEntity):
 
 class Revision(AnyEntity):
     """customized class for Revision entities"""
-    id = 'Revision'
+    __regid__ ='Revision'
     fetch_attrs, fetch_order = fetch_config(['revision', 'changeset', 'author',
                                              'description', 'creation_date'])
     __implements__ = AnyEntity.__implements__ + (IPrevNext,)
 
     def dc_title(self):
         if self.changeset:
-            return self.req._('revision #%(rev)s:%(changeset)s') % {
+            return self._cw._('revision #%(rev)s:%(changeset)s') % {
                 'rev': self.revision, 'changeset': self.changeset}
         else:
-            return self.req._('revision #%s') % self.revision
+            return self._cw._('revision #%s') % self.revision
 
     def dc_long_title(self):
-        return self.req._('%(rev)s of repository %(repo)s') % {
+        return self._cw._('%(rev)s of repository %(repo)s') % {
             'rev': self.dc_title(), 'repo': self.repository.dc_title()}
 
     def sortvalue(self, rtype=None):
@@ -175,7 +175,7 @@ class Revision(AnyEntity):
 
     def previous_entity(self): # IPrevNext
         # may have multiple parents, take the first one in the same branch...
-        rset = self.req.execute('Any X LIMIT 1 WHERE R parent_revision X , '
+        rset = self._cw.execute('Any X LIMIT 1 WHERE R parent_revision X , '
                                 'R eid %(r)s, X branch %(branch)s',
                                 {'r': self.eid, 'branch': self.branch})
         if rset:
@@ -183,7 +183,7 @@ class Revision(AnyEntity):
 
     def next_entity(self): # IPrevNext
         # may have multiple children, take the first one in the same branch...
-        rset = self.req.execute('Any X LIMIT 1 WHERE X parent_revision R , '
+        rset = self._cw.execute('Any X LIMIT 1 WHERE X parent_revision R , '
                                 'R eid %(r)s, X branch %(branch)s',
                                 {'r': self.eid, 'branch': self.branch})
         if rset:
@@ -201,7 +201,7 @@ class Revision(AnyEntity):
                 repoeid = self.linked_to('from_repository', 'subject', remove=False)[0]
             except IndexError:
                 raise RequestError('missing repository information')
-            self.req.set_shared_data('vcsrepoeid', repoeid, querydata=True)
+            self._cw.set_shared_data('vcsrepoeid', repoeid, querydata=True)
 
     # navigation in versioned content #########################################
 
@@ -212,17 +212,17 @@ class Revision(AnyEntity):
 
 class VersionedFile(AnyEntity):
     """customized class for VersionedFile entities"""
-    id = 'VersionedFile'
+    __regid__ ='VersionedFile'
     fetch_attrs, fetch_order = fetch_config(['directory', 'name'])
 
     # XXX branches
     def dc_title(self):
         if self.deleted_in_branch():
-            return '%s (%s)' % (self.path, self.req._('DELETED'))
+            return '%s (%s)' % (self.path, self._cw._('DELETED'))
         return self.path
 
     def dc_long_title(self):
-        return self.req._('%(path)s (from repository %(repotype)s:%(repo)s)') % {
+        return self._cw._('%(path)s (from repository %(repotype)s:%(repo)s)') % {
             'path': self.dc_title(), 'repo': self.repository.path,
             'repotype': self.repository.type}
 
@@ -259,7 +259,7 @@ class VersionedFile(AnyEntity):
     def version_content(self, revnum):
         if revnum is None:
             return self.branch_head()
-        rset = self.req.execute(
+        rset = self._cw.execute(
             'Any C,VF,R WHERE C content_for VF, C from_revision R, '
             'R revision %(rnum)s, VF eid %(x)s',
             {'rnum' : int(revnum), 'x' : self.eid}, 'x')
@@ -274,7 +274,7 @@ class VersionedFile(AnyEntity):
         """
         if branch is _MARKER:
             branch = self.repository.default_branch()
-        rset = self.req.execute(
+        rset = self._cw.execute(
             'Any MAX(V) WHERE X eid %(x)s, V content_for X, V at_revision REV, '
             'REV branch %(branch)s',
             {'x': self.eid, 'branch': branch}, 'x')
@@ -299,13 +299,13 @@ class VersionedFile(AnyEntity):
         if not isinstance(self.branch_head(kwargs.get('branch', _MARKER)),
                           VersionContent):
             # already deleted
-            raise QueryError(self.req._('%s is already deleted from the vcs')
+            raise QueryError(self._cw._('%s is already deleted from the vcs')
                              % self.path)
         if rev is None:
             if not 'msg' in kwargs:
-                kwargs['msg'] = self.req._('deleted %s') % self.dc_title()
+                kwargs['msg'] = self._cw._('deleted %s') % self.dc_title()
             rev = self.repository.make_revision(**kwargs)
-        self.req.execute(
+        self._cw.execute(
             'INSERT DeletedVersionContent D: D content_for X, '
             'D from_revision R WHERE X eid %(x)s, R eid %(r)s',
             {'x' : self.eid, 'r' : rev.eid}, ('x', 'r'))
@@ -319,24 +319,24 @@ class VersionedFile(AnyEntity):
         """
         if rev is None:
             rev = self.repository.make_revision(**kwargs)
-        return self.req.execute(queries.new_file_content_rql(),
+        return self._cw.execute(queries.new_file_content_rql(),
                                 {'vfeid' : self.eid, 'reveid' : rev.eid,
                                  'data' : Binary(stream.read())}).get_entity(0, 0)
 
 
 class DeletedVersionContent(AnyEntity):
     """customized class for DeletedVersionContent entities"""
-    id = 'DeletedVersionContent'
+    __regid__ ='DeletedVersionContent'
     fetch_attrs, fetch_order = fetch_config(['from_revision', 'content_for'], order='DESC')
     __implements__ = AnyEntity.__implements__ + (IPrevNext,)
 
     def dc_title(self):
-        return self.req._('%(file)s DELETED (revision %(revision)s)') % {
+        return self._cw._('%(file)s DELETED (revision %(revision)s)') % {
             'file': self.file.path, 'revision': self.rev.revision}
 
     def dc_long_title(self):
         rev = self.rev
-        return self.req._('%(file)s DELETED (revision %(revision)s on %(date)s by %(author)s)') % {
+        return self._cw._('%(file)s DELETED (revision %(revision)s on %(date)s by %(author)s)') % {
             'file': self.file.path, 'revision': rev.revision,
             'author': rev.author, 'date': rev.printable_value('creation_date')}
 
@@ -347,7 +347,7 @@ class DeletedVersionContent(AnyEntity):
         return self.rev.dc_description(format)
 
     def previous_entity(self): # IPrevNext
-        rset = self.req.execute('Any PV,R,PVR,VF ORDERBY PVR DESC LIMIT 1 '
+        rset = self._cw.execute('Any PV,R,PVR,VF ORDERBY PVR DESC LIMIT 1 '
                                 'WHERE PV from_revision R, R revision PVR, '
                                 'R branch %(b)s, PV content_for VF, '
                                 'R revision < %(r)s, VF eid %(vf)s',
@@ -357,7 +357,7 @@ class DeletedVersionContent(AnyEntity):
             return rset.get_entity(0, 0)
 
     def next_entity(self): # IPrevNext
-        rset = self.req.execute('Any NV,R,NVR,VF ORDERBY NVR ASC LIMIT 1 '
+        rset = self._cw.execute('Any NV,R,NVR,VF ORDERBY NVR ASC LIMIT 1 '
                                 'WHERE NV from_revision R, R revision NVR, '
                                 'R branch %(b)s, NV content_for VF, '
                                 'R revision > %(r)s, VF eid %(vf)s',
@@ -414,16 +414,16 @@ class DeletedVersionContent(AnyEntity):
 
 class VersionContent(DeletedVersionContent):
     """customized class for VersionContent entities"""
-    id = 'VersionContent'
+    __regid__ = 'VersionContent'
     __implements__ = DeletedVersionContent.__implements__ + (IDownloadable,)
 
     def dc_title(self):
-        return self.req._('%(file)s (revision %(revision)s)') % {
+        return self._cw._('%(file)s (revision %(revision)s)') % {
             'file': self.file.path, 'revision': self.revision}
 
     def dc_long_title(self):
         rev = self.rev
-        return self.req._('%(file)s (revision %(revision)s on %(date)s by %(author)s)') % {
+        return self._cw._('%(file)s (revision %(revision)s on %(date)s by %(author)s)') % {
             'file': self.file.path, 'revision': rev.revision,
             'author': rev.author, 'date': rev.printable_value('creation_date')}
 
@@ -457,4 +457,4 @@ class VersionContent(DeletedVersionContent):
 
     def size(self):
         rql = "Any LENGTH(D) WHERE X eid %(eid)s, X data D"
-        return self.req.execute(rql, {'eid': self.eid})[0][0]
+        return self._cw.execute(rql, {'eid': self.eid})[0][0]
