@@ -12,18 +12,19 @@ import os
 from logilab.mtconverter import need_guess, guess_mimetype_and_encoding
 
 from cubicweb import QueryError, ValidationError, Binary
-from cubicweb.server.hooksmanager import Hook
-from cubicweb.server.pool import PreCommitOperation, Operation
+from cubicweb.server import hook
+from cubicweb.server.hook import Hook, Operation
+from cubicweb.selectors import implements
 
 from cubes.vcsfile import IMMUTABLE_ATTRIBUTES, bridge
 
 def missing_relation_error(entity, rtype):
     # use __ since msgid recorded in cw, we don't want to translate it in
     # this cube
-    __ = entity.req._
+    __ = entity._cw._
     msg = __('at least one relation %(rtype)s is required on %(etype)s (%(eid)s)')
     errors = {'from_repository': msg % {'rtype': __(rtype),
-                                        'etype': __(entity.id),
+                                        'etype': __(entity.__regid__),
                                         'eid': entity.eid}}
     return ValidationError(entity.eid, errors)
 
@@ -37,8 +38,10 @@ class ServerStartupHook(Hook):
     """synchronize repository on server startup, and install attribute map
     on the system source sql generator
     """
+    __regid__ = 'serverstartuphook'
     events = ('server_startup',)
-    def call(self, repo):
+    def __call__(self):
+        repo = self.repo
         repo.system_source.map_attribute('VersionContent', 'data',
                                          _generate_vc_data)
         repo.looping_task(repo.config.get('check-revision-interval', 5*60),
@@ -48,15 +51,16 @@ class ServerStartupHook(Hook):
 
 class AddRepositoryHook(Hook):
     """add repository eid to vcs bridge cache"""
+    __regid__ = 'add_repository_hook'
     events = ('before_add_entity', )
-    accepts = ('Repository',)
+    __select__ = Hook.__select__ & implements('Repository')
 
-    def call(self, session, entity):
+    def __call__(self):
         try:
             # check and register the repository into the bridge
-            bridge.cache_handler_for_repository(entity)
+            bridge.cache_handler_for_repository(self.entity)
         except bridge.VCSException, ex:
-            raise ex.to_validation_error(session._)
+            raise ex.to_validation_error(self._cw._)
 
 # internals to be able to create new vcs repo revision using rql queries #######
 
@@ -65,7 +69,7 @@ def _vc_prepare(entity, vcsrepoeid=None):
         vfeid = entity['content_for']
     except KeyError:
         raise missing_relation_error(entity, 'content_for')
-    session = entity.req
+    session = entity._cw
     if vcsrepoeid is None:
         # retrieve associated VersionedFile instance
         vf = session.execute('Any X,D,N,R WHERE X name N, X directory D,'
@@ -87,7 +91,7 @@ def _vc_vf(entity):
             vfeid = entity['content_for']
         except KeyError, ex:
             raise missing_relation_error(entity, 'content_for')
-        session = entity.req
+        session = entity._cw
         vf = session.execute(
             'Any X, R, FD, FN WHERE X directory FD, X name FN, X eid %(x)s, '
             'X from_repository R', {'x': vfeid}, 'x').get_entity(0, 0)
@@ -119,10 +123,13 @@ class VCTransactionOp(Operation):
 
 
 class AddRevisionHook(Hook):
+    __regid__ = 'add_revision_hook'
     events = ('before_add_entity',)
-    accepts = ('Revision',)
+    __select__ = Hook.__select__ & implements('Revision')
 
-    def call(self, session, entity):
+    def __call__(self):
+        entity = self.entity
+        session = self._cw
         if not entity.get('revision'):
             # new revision to be created, set a temporary value
             entity['revision'] = 0
@@ -153,10 +160,13 @@ class AddRevisionHook(Hook):
 
 
 class AddVersionContentHook(Hook):
+    __regid__ = 'add_version_content_hook'
     events = ('before_add_entity',)
-    accepts = ('VersionContent',)
+    __select__ = Hook.__select__ & implements('VersionContent')
 
-    def call(self, session, entity):
+    def __call__(self):
+        session = self._cw
+        entity = self.entity
         data = self.get_data(entity)
         # save data for usage in after_add_entity hook below
         session.transaction_data[(entity.eid, 'data')] = data
@@ -179,7 +189,7 @@ class AddVersionContentHook(Hook):
                                                data)
 
     def get_data(self, entity):
-        session = entity.req
+        session = entity._cw
         if session.is_internal_session:
             vf = _vc_vf(entity)
             vcsrepohdlr = bridge.repository_handler(vf.repository.eid)
@@ -194,46 +204,50 @@ class AddVersionContentHook(Hook):
 
 
 class AfterAddVersionContentHook(Hook):
+    __regid__ = 'after_add_version_content_hook'
     events = ('after_add_entity',)
-    accepts = ('VersionContent',)
-    def call(self, session, entity):
+    __select__ = Hook.__select__ & implements('VersionContent')
+    def __call__(self):
         # restore data for full text indexation
-        entity['data'] = session.transaction_data.pop((entity.eid, 'data'))
+        self.entity['data'] = self._cw.transaction_data.pop((self.entity.eid, 'data'))
 
 
 class AddDeletedVersionContentHook(Hook):
+    __regid__ = 'add_deleted_version_content_hook'
     events = ('before_add_entity',)
-    accepts = ('DeletedVersionContent',)
+    __select__ = Hook.__select__ & implements('DeletedVersionContent')
 
-    def call(self, session, entity):
+    def __call__(self):
         # skip further processing if the revision is being imported from the
         # vcs repository
-        if session.is_internal_session:
+        if self._cw.is_internal_session:
             return
-        vcsrepohdlr, transaction = _vc_prepare(entity)
-        vf = _vc_vf(entity)
-        vcsrepohdlr.add_versioned_file_deleted_content(session, transaction, vf,
-                                                       entity)
+        vcsrepohdlr, transaction = _vc_prepare(self.entity)
+        vf = _vc_vf(self.entity)
+        vcsrepohdlr.add_versioned_file_deleted_content(self._cw, transaction, vf,
+                                                       self.entity)
 
 
 class AddVersionedFileHook(Hook):
+    __regid__ = 'add_versioned_file_hook'
     events = ('before_add_entity',)
-    accepts = ('VersionedFile',)
+    __select__ = Hook.__select__ & implements('VersionedFile')
 
-    def call(self, session, entity):
+    def __call__(self):
         # skip further processing if the revision is being imported from the
         # vcs repository
-        if session.is_internal_session:
+        if self._cw.is_internal_session:
             return
-        CheckVersionedFileOp(session, entity=entity)
+        CheckVersionedFileOp(self._cw, entity=self.entity)
 
 # ancestor_revision synchro ####################################################
 
 class AddParentRevisionHook(Hook):
+    __regid__ = 'add_parent_revision_hook'
     events = ('after_add_relation',)
-    accepts = ('parent_revision',)
+    __select__ = Hook.__select__ & hook.match_rtype('parent_revision')
 
-    def call(self, session, fromeid, rtype, toeid):
+    def __call__(self):
         # ancestor relation may already be set
         # if session.unsafe_execute('Any X WHERE X eid %(x)s, Y eid %(y)s, '
         #                           'X ancestor_revision Y',
@@ -247,18 +261,18 @@ class AddParentRevisionHook(Hook):
         #     'WHERE R eid %(rev)s, PR eid %(prev)s, PR ancestor_revision AR, '
         #     'NOT R ancestor_revision AR',
         #     {'rev': fromeid, 'prev': toeid}, 'rev')
-        session.system_sql('INSERT INTO ancestor_revision_relation(eid_from,eid_to) '
-                           'SELECT %s, %s '
-                           'WHERE NOT EXISTS('
-                           '  SELECT 1 FROM ancestor_revision_relation AS ar '
-                           '  WHERE ar.eid_from=%s AND ar.eid_to=%s'
-                           ')' % (fromeid, toeid, fromeid, toeid))
-        session.system_sql('INSERT INTO ancestor_revision_relation(eid_from,eid_to) '
-                           'SELECT %s, ar.eid_to FROM ancestor_revision_relation AS ar '
-                           'WHERE ar.eid_from=%s AND NOT EXISTS('
-                           '  SELECT 1 FROM ancestor_revision_relation AS ar2 '
-                           '  WHERE ar2.eid_from=%s AND ar2.eid_to=ar.eid_to'
-                           ')' % (fromeid, toeid, fromeid))
+        self._cw.system_sql('INSERT INTO ancestor_revision_relation(eid_from,eid_to) '
+                            'SELECT %s, %s '
+                            'WHERE NOT EXISTS('
+                            '  SELECT 1 FROM ancestor_revision_relation AS ar '
+                            '  WHERE ar.eid_from=%s AND ar.eid_to=%s'
+                            ')' % (self.eidfrom, self.eidto, self.eidfrom, self.eidto))
+        self._cw.system_sql('INSERT INTO ancestor_revision_relation(eid_from,eid_to) '
+                            'SELECT %s, ar.eid_to FROM ancestor_revision_relation AS ar '
+                            'WHERE ar.eid_from=%s AND NOT EXISTS('
+                            '  SELECT 1 FROM ancestor_revision_relation AS ar2 '
+                            '  WHERE ar2.eid_from=%s AND ar2.eid_to=ar.eid_to'
+                            ')' % (self.eidfrom, self.eidto, self.eidfrom))
 
 # safety belts #################################################################
 
@@ -271,7 +285,7 @@ def _check_in_transaction(vf_or_rev):
     except IndexError:
         raise missing_relation_error(vf_or_rev, 'from_repository')
     try:
-        transactions = vcsrepo.req.transaction_data['vctransactions']
+        transactions = vcsrepo._cw.transaction_data['vctransactions']
         transaction = transactions[vcsrepo.eid]
     except KeyError:
         raise QueryError('no transaction in progress for repository %s'
@@ -279,14 +293,14 @@ def _check_in_transaction(vf_or_rev):
     return transaction
 
 
-class CheckVersionedFileOp(PreCommitOperation):
+class CheckVersionedFileOp(Operation):
     """check transaction consistency when adding new revision using rql queries
     """
     def precommit_event(self):
         _check_in_transaction(self.entity)
 
 
-class CheckRevisionOp(PreCommitOperation):
+class CheckRevisionOp(Operation):
     """check transaction consistency when adding new revision using rql queries
     """
     def precommit_event(self):
@@ -300,33 +314,36 @@ class CheckRevisionOp(PreCommitOperation):
 
 
 class CheckImmutalbeAttributeHook(Hook):
+    __regid__ = 'check_immutable_attribute_hook'
     events = ('before_update_entity',)
-    accepts = ('Revision', 'DeletedVersionContent', 'VersionContent')
+    __select__ = Hook.__select__ & implements('Revision', 'DeletedVersionContent',
+                                              'VersionContent')
 
-    def call(self, session, entity):
-        for attr in entity.keys():
+    def __call__(self):
+        for attr in self.entity.keys():
             if attr == 'eid':
                 continue
-            if '%s.%s' % (entity.id, attr) in IMMUTABLE_ATTRIBUTES:
+            if '%s.%s' % (self.entity.__regid__, attr) in IMMUTABLE_ATTRIBUTES:
                 raise QueryError('%s attribute is not editable' % attr)
 
 
 class UpdateRepositoryHook(Hook):
     """add repository eid to vcs bridge cache"""
+    __regid__ = 'update_repository_hook'
     events = ('before_update_entity', )
-    accepts = ('Repository',)
-    def call(self, session, entity):
+    __select__ = Hook.__select__ & implements('Repository')
+    def __call__(self):
         # XXX check value actually changed
         try:
-            edited = entity.edited_attributes
+            edited = self.entity.edited_attributes
         except AttributeError:
-            edited = entity
+            edited = self.entity
         if 'path' in edited:
-            msg = session._('updating path attribute of a repository isn\'t '
+            msg = self._cw._('updating path attribute of a repository isn\'t '
                             'supported. Delete it and add a new one.')
             raise QueryError(msg)
         if 'type' in edited:
-            msg = session._('updating type attribute of a repository isn\'t '
+            msg = self._cw._('updating type attribute of a repository isn\'t '
                             'supported. Delete it and add a new one.')
             raise QueryError(msg)
 
@@ -337,34 +354,35 @@ class ClassifyVersionedFileHook(Hook):
     """classifies VersionedFile automatically according to their path in the
     repository (require cubicweb-tag and/or cubicweb-folder installed)
     """
+    __regid__ = 'classify_versioned_file_hook'
     events = ('after_add_entity', )
-    accepts = ('VersionedFile',)
+    __select__ = Hook.__select__ & implements('VersionedFile')
 
-    def call(self, session, entity):
+    def __call__(self):
         try:
-            rschema = self.schema['tags']
-            support_tags = rschema.has_rdef('Tag', entity.e_schema)
+            rschema = self._cw.vreg.schema['tags']
+            support_tags = ('Tag', self.entity.e_schema) in rschema.rdefs
         except KeyError:
             support_tags = False
         try:
-            rschema = self.schema['filed_under']
-            support_folders = rschema.has_rdef(entity.e_schema, 'Folder')
+            rschema = self._cw.vreg.schema['filed_under']
+            support_folders = (self.entity.e_schema, 'Folder') in rschema.rdefs
         except KeyError:
             support_folders = False
         if not (support_tags or support_folders):
             return
-        for directory in entity.directory.split(os.sep):
+        for directory in self.entity.directory.split(os.sep):
             if not directory:
                 continue
             if support_tags:
-                rset = session.execute('Tag X WHERE X name %(name)s',
+                rset = self._cw.execute('Tag X WHERE X name %(name)s',
                                        {'name': directory})
                 if rset:
-                    session.execute('SET T tags X WHERE X eid %(x)s, T eid %(t)s',
-                                    {'x': entity.eid, 't': rset[0][0]}, 'x')
+                    self._cw.execute('SET T tags X WHERE X eid %(x)s, T eid %(t)s',
+                                    {'x': self.entity.eid, 't': rset[0][0]}, 'x')
             if support_folders:
-                rset = session.execute('Folder X WHERE X name %(name)s',
+                rset = self._cw.execute('Folder X WHERE X name %(name)s',
                                        {'name': directory})
                 if rset:
-                    session.execute('SET X filed_under F WHERE X eid %(x)s, F eid %(f)s',
-                                    {'x': entity.eid, 'f': rset[0][0]}, 'x')
+                    self._cw.execute('SET X filed_under F WHERE X eid %(x)s, F eid %(f)s',
+                                    {'x': self.entity.eid, 'f': rset[0][0]}, 'x')
