@@ -44,7 +44,7 @@ class HGRepository(repo.VCSRepository):
         # actual rev is the *number* of revision, latest rev the highest
         # revision number while hg revisions start at 0 -> - 1
         actualrev = bw_nb_revisions(repo.changelog) - 1
-        session = repoentity.req
+        session = repoentity._cw
         latestrev = repoentity.latest_known_revision()
         if actualrev < latestrev:
             # striped repo
@@ -52,7 +52,7 @@ class HGRepository(repo.VCSRepository):
             # revisions has changed due to the strip
             self.warning('strip detected ? latest known revision is %s, latest '
                          'repository revision is %s', latestrev, actualrev)
-            session.execute('DELETE Revision X WHERE X revision >= %(rev)s',
+            session.execute('DELETE Revision X WHERE X revision > %(rev)s',
                             {'rev': actualrev})
             return
         self.info('hg repo %s: known revisions up to %s, repo revision %s',
@@ -72,7 +72,7 @@ class HGRepository(repo.VCSRepository):
                 session.set_pool()
 
     def import_revision(self, repoentity, repo, i):
-        session = repoentity.req
+        session = repoentity._cw
         execute = session.execute
         node = repo.changelog.node(i)
         changeset = unicode(short_hex(node))
