@@ -1,7 +1,7 @@
 """repository abstraction for a subversion repository
 
 :organization: Logilab
-:copyright: 2007-2009 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:copyright: 2007-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 __docformat__ = "restructuredtext en"
@@ -45,9 +45,11 @@ class SVNRepository(repo.VCSRepository):
             return
         callbacks = ra.Callbacks()
         #ra_ctx = ra.open2('file://' + self.path, callbacks, None, None)
-        latestrev = rev = repoentity.latest_known_revision()
+        rev = repoentity.latest_known_revision()
+        if rev == -1:
+            rev = 0
         actualrev = fs.youngest_rev(fsrep)
-        session = repoentity.req
+        session = repoentity._cw
         while rev < actualrev:
             base_root = fs.revision_root(fsrep, rev)
             rev += 1
@@ -174,7 +176,7 @@ class SVNImporter(delta.Editor):
     def __init__(self, repoentity, fsrep, base_root, rev):
         self.repoeid = repoentity.eid
         self.encoding = repoentity.encoding
-        self.session = repoentity.req
+        self.session = repoentity._cw
         path_filter = repoentity.subpath
         if isinstance(path_filter, unicode):
             # if we don't encode we may get unicode error when comparing files'
