@@ -15,7 +15,7 @@ class Repository(EntityType):
     """a local subversion repository which will be used as versionned content
     entity source
     """
-    permissions = {
+    __permissions__ = {
         'read':   ('managers', 'users'),
         'add':    ('managers',),
         'update': ('managers',),
@@ -34,7 +34,7 @@ class Repository(EntityType):
 
 
 class Revision(EntityType):
-    permissions = {
+    __permissions__ = {
         'read':   ('managers', 'users', 'guests'),
         'add':    ('managers', 'users',),
         'update': ('managers', 'owners'),
@@ -64,7 +64,7 @@ class Revision(EntityType):
 
 class VersionedFile(EntityType):
     """a file stored in a versioned source"""
-    permissions = {
+    __permissions__ = {
         'read':   ('managers', 'users', 'guests'),
         'add':    ('managers', 'users',),
         'update': (),
@@ -79,7 +79,7 @@ class VersionedFile(EntityType):
 
 class DeletedVersionContent(EntityType):
     """represent a revision where a versioned file has been deleted"""
-    permissions = {
+    __permissions__ = {
         'read':   ('managers', 'users', 'guests'),
         'add':    ('managers', 'users',),
         'update': ('managers', 'owners'),
@@ -117,7 +117,7 @@ class from_revision(RelationType):
     inlined = True
 
 class at_revision(RelationType):
-    permissions = {
+    __permissions__ = {
         'read':   ('managers', 'users', 'guests'),
         'add':    (),
         'delete': (),
