@@ -1,17 +1,3 @@
-# register VERSION_DATA stored procedure #######################################
-
-from rql.utils import register_function, FunctionDescr
-
-class version_data(FunctionDescr):
-    supported_backends = ('postgres', 'sqlite',)
-    rtype = 'Bytes'
-
-try:
-    register_function(version_data)
-except AssertionError:
-    pass
-
-
 # repository specific stuff ####################################################
 
 try:
