@@ -11,7 +11,8 @@ from logilab.mtconverter import TransformError, xml_escape
 
 from cubicweb.selectors import implements
 from cubicweb.view import EntityView
-from cubicweb.common import mttransforms, tags
+from cubicweb.mttransforms import ENGINE
+from cubicweb import tags
 from cubicweb.web import uicfg
 from cubicweb.web.views import (ibreadcrumbs, idownloadable,
                                 baseviews, primary, tabs)
@@ -31,7 +32,7 @@ def render_entity_summary(self, entity):
     if entity.description:
         self.w(tags.div(entity.description, klass='summary'))
     if not entity.is_head(entity.rev.branch):
-        msg = self.req._('this file has newer revisions')
+        msg = self._cw._('this file has newer revisions')
         self.w(tags.div(msg, klass='warning'))
 
 
@@ -42,13 +43,14 @@ class RepositoryPrimaryView(tabs.TabsMixin, primary.PrimaryView):
     default_tab = 'repositoryinfo_tab'
 
     def cell_call(self, row, col):
-        entity = self.complete_entity(row, col)
+        entity = self.cw_rset.get_entity(row, col)
+        entity.complete()
         self.render_entity_title(entity)
         self.render_tabs(self.tabs, self.default_tab, entity)
 
 
 class RepositoryInfoTab(primary.PrimaryView):
-    id = 'repositoryinfo_tab'
+    __regid__ = 'repositoryinfo_tab'
     __select__ = implements('Repository')
 
     def render_entity_title(self, entity):
@@ -56,40 +58,40 @@ class RepositoryInfoTab(primary.PrimaryView):
 
     def render_entity_attributes(self, entity):
         super(RepositoryInfoTab, self).render_entity_attributes(entity)
-        rset = self.req.execute('Any REV, REVB, REVN ORDERBY REVN DESC '
+        rset = self._cw.execute('Any REV, REVB, REVN ORDERBY REVN DESC '
                                 'WHERE REV branch REVB, REV revision REVN, REV from_repository R, '
                                 'R eid %(r)s, NOT X parent_revision REV',
                                 {'r': entity.eid}, 'r')
         if rset:
-            self.w('<h3>%s</h3>' % self.req._('heads'))
+            self.w('<h3>%s</h3>' % self._cw._('heads'))
             self.wview('table', rset)
 
 
 class RepositoryFilesTab(EntityView):
-    id = 'repositoryfiles_tab'
+    __regid__ = 'repositoryfiles_tab'
     __select__ = implements('Repository')
 
     def cell_call(self, row, col):
         entity = self.rset.get_entity(row, col)
         filesrql = entity.related_rql('from_repository', 'object', ('VersionedFile',))
-        self.wview('list', self.req.execute(filesrql, {'x': entity.eid}, 'x'), 'noresult')
+        self.wview('list', self._cw.execute(filesrql, {'x': entity.eid}, 'x'), 'noresult')
 
 
 class RepositoryHistoryTab(EntityView):
-    id = 'repositoryhistory_tab'
+    __regid__ = 'repositoryhistory_tab'
     __select__ = implements('Repository')
 
     def cell_call(self, row, col):
         entity = self.rset.get_entity(row, col)
         revisionsrql = entity.related_rql('from_repository', 'object', ('Revision',))
-        self.wview('table', self.req.execute(revisionsrql, {'x': entity.eid}, 'x'), 'noresult')
+        self.wview('table', self._cw.execute(revisionsrql, {'x': entity.eid}, 'x'), 'noresult')
 
 
 class DVCPrimaryView(primary.PrimaryView):
     __select__ = implements('DeletedVersionContent')
 
     def render_entity_title(self, entity):
-        title = self.req._('Revision %(revision)s of %(file)s: DELETED') % {
+        title = self._cw._('Revision %(revision)s of %(file)s: DELETED') % {
             'revision': entity.revision, 'file': entity.file.view('oneline')}
         self.w('<h1>%s</h1>' % title)
 
@@ -100,7 +102,7 @@ class VCPrimaryView(idownloadable.IDownloadablePrimaryView):
     __select__ = implements('VersionContent')
 
     def render_entity_title(self, entity):
-        title = self.req._('Revision %(revision)s of %(file)s') % {
+        title = self._cw._('Revision %(revision)s of %(file)s') % {
             'revision': entity.revision, 'file': entity.file.view('oneline')}
         self.w('<h1>%s</h1>' % title)
 
@@ -112,8 +114,8 @@ class VCMetaDataView(baseviews.MetaDataView):
     __select__ = implements('VersionContent', 'DeletedVersionContent')
 
     def cell_call(self, row, col):
-        _ = self.req._
-        entity = self.entity(row, col)
+        _ = self._cw._
+        entity = self.cw_rset.get_entity(row, col)
         self.w(u'<div class="metadata">')
         self.w(u'#%s - ' % entity.eid)
         self.w(u'<span>%s</span> ' % _('revision %s of') % entity.revision)
@@ -121,7 +123,7 @@ class VCMetaDataView(baseviews.MetaDataView):
                % xml_escape(entity.file.path))
         self.w(u'<span>%s</span> ' % _('created on'))
         self.w(u'<span class="value">%s</span>'
-               % self.format_date(entity.creation_date))
+               % entity.rev.printable_value('creation_date'))
         if entity.author:
             self.w(u'&nbsp;<span>%s</span> ' % _('by'))
             self.w(tags.span(entity.author, klass='value'))
@@ -143,12 +145,12 @@ class VFPrimaryView(primary.PrimaryView):
                 self.wview('image', head.rset, row=head.row)
             else:
                 try:
-                    if mttransforms.ENGINE.has_input(contenttype):
+                    if ENGINE.has_input(contenttype):
                         self.w(head.printable_value('data'))
                 except TransformError:
                     pass
                 except Exception, ex:
-                    msg = self.req._("can't display data, unexpected error: %s") % ex
+                    msg = self._cw._("can't display data, unexpected error: %s") % ex
                     self.w('<div class="error">%s</div>' % xml_escape(msg))
         self.w(u'</div>')
 
@@ -186,18 +188,18 @@ class RevisionPrimaryView(primary.PrimaryView):
         if versioned:
             self.w(u'<table class="listing">')
             self.w(u'<tr><th>%s</th></tr>' %
-                   self.req._('objects concerned by this revision'))
+                   self._cw._('objects concerned by this revision'))
             for obj in versioned:
                 self.w(u'<tr><td><a href="%s">%s</a></td></tr>' % (
                     obj.absolute_url(), xml_escape(obj.dc_title())))
             self.w(u'</table>')
         else:
-            self.w(u'<p>%s</p>' % self.req._('this revision hasn\'t modified any files'))
+            self.w(u'<p>%s</p>' % self._cw._('this revision hasn\'t modified any files'))
 
 
 
 class DVCBreadCrumbView(ibreadcrumbs.BreadCrumbView):
-    id = 'breadcrumbtext'
+    __regid__ = 'breadcrumbtext'
     __select__ = implements('VersionContent', 'DeletedVersionContent')
 
     def cell_call(self, row, col):
